@@ -1,4 +1,4 @@
-from . import TimeSlot
+from .timeslot import TimeSlot
 from pprint import pprint
 
 class Program:
